@@ -6,18 +6,13 @@ PARSERS = {
     "ssa": ssa.parse,
     "srt": srt.parse,
     "sub": sub.parse,
-    "txt": txt.parse
+    "txt": txt.parse,
 }
 
 
-def parse(
-        path: str,
-        subtitle_type: str = None,
-        encoding: str = "utf-8",
-        **kwargs
-):
+def parse(path: str, subtitle_type: str = None, encoding: str = "utf-8", **kwargs):
     if not subtitle_type:
-        subtitle_type = path[path.rfind(".") + 1:]
+        subtitle_type = path[path.rfind(".") + 1 :]
 
     parser = PARSERS.get(subtitle_type.lower())
 
